local BrothelSystemMod = ...


------------------------------BROTHEL---------------------------------

-- Register core prefab nodes
BrothelSystemMod:registerAssetId("models/brothel.fbx/Prefab/Brothel/Core/RootPart", "BROTHEL_CORE_ROOT_PREFAB")
BrothelSystemMod:registerAssetId("models/brothel.fbx/Prefab/Brothel/Core/TopPart", "BROTHEL_CORE_TOP_PREFAB")
BrothelSystemMod:registerAssetId("models/brothel.fbx/Prefab/Brothel/Core/Tiling1Part", "BROTHEL_CORE_TILING1_PREFAB")
BrothelSystemMod:registerAssetId("models/brothel.fbx/Prefab/Brothel/Core/Tiling2Part", "BROTHEL_CORE_TILING2_PREFAB")
BrothelSystemMod:registerAssetId("models/brothel.fbx/Prefab/Brothel/Core/Tiling3Part", "BROTHEL_CORE_TILING3_PREFAB")

-- Register door prefab nodes
BrothelSystemMod:registerAssetId("models/brothel.fbx/Prefab/Brothel/DoorAPart", "BROTHEL_DOOR_A_PREFAB")

--------------------------------------------------------------------------

-- Create default building part registering function 
function registerDefaultBuildingPart(_nodePrefix)
	BrothelSystemMod:register({
		DataType = "BUILDING_PART",
		Id = _nodePrefix .. "_PART",
		Mover = { DataType = "BUILDING_PART_MOVER" },
		ConstructorData = { DataType = "BUILDING_CONSTRUCTOR_DEFAULT", CoreObjectPrefab = _nodePrefix .. "_PREFAB" }
	})
end

local defaultNodePrefixList = {
	"BROTHEL_CORE_TOP",
	"BROTHEL_CORE_TILING1",
	"BROTHEL_CORE_TILING2",
	"BROTHEL_CORE_TILING3"
}

-- Register simple building part assets
for i, nodePrefix in ipairs(defaultNodePrefixList) do
	registerDefaultBuildingPart(nodePrefix)
end

--------------------------------------------------------------------------

BrothelSystemMod:register({ 
	DataType = "BUILDING_FUNCTION_WORKPLACE",
	Id = "BROTHEL_CORE_FUNCTION",
	WorkerCapacity = 4,
	RelatedJob = { Job = "TRANSPORTER", Behavior = "WORK_BEHAVIOR" },
	ResourceProduced = { -- Necessarily a list of 'RESOURCE_QUANTITY_PAIR', no need to specify the DataType	
		{ Resource = "BARREL", Quantity = 5 }
	}
})

-- Register the brothel core part
BrothelSystemMod:register({
	DataType = "BUILDING_PART",
	Id = "BROTHEL",
	Name = "BROTHEL_NAME",
	Description = "BROTHEL_DESC",
	Category = "CORE",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = "BROTHEL_CORE_ROOT_PREFAB",
		EndPart = "BROTHEL_CORE_TOP_PART",
		FillerList = {
			"BROTHEL_CORE_TILING1_PART",
			"BROTHEL_CORE_TILING2_PART",
			"BROTHEL_CORE_TILING3_PART"
		},
		BasementFillerList = {
			"BROTHEL_CORE_TILING1_PART",
			"BROTHEL_CORE_TILING2_PART",
			"BROTHEL_CORE_TILING3_PART"
		},
	},
	BuildingFunction = "BROTHEL_CORE_FUNCTION",
	Cost = {
		UpkeepCost = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "GOLD", Quantity = 3 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "WOOD", Quantity = 30 },
			{ Resource = "STONE", Quantity = 20 }
		}
	}
})

-- Register the brothel door A part
BrothelSystemMod:register({
	DataType = "BUILDING_PART",
	Id = "BROTHEL_DOOR_A_PART",
	Name = "BROTHEL_DOOR_A_NAME",
	Description = "BROTHEL_DOOR_A_DESC",
	Category = "DOOR",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "BROTHEL_DOOR_A_PREFAB"
	},
	Cost = {
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "WOOD", Quantity = 5 }
		}
	}
})


